@@ -18,7 +18,7 @@ from scipy.spatial import KDTree
 from scipy.stats import norm
 
 from pyridy import config
-from pyridy.config import cm
+from pyridy.config import cm, options
 from pyridy.osm import OSM, OSMRailwayLine
 from pyridy.osm.utils import is_point_within_line_projection, project_point_onto_line
 from pyridy.utils import Sensor, AccelerationSeries, LinearAccelerationSeries, MagnetometerSeries, OrientationSeries, \
@@ -313,9 +313,21 @@ class RDYFile:
                 self.sync_method = "device_time"
                 self._synchronize()
         elif self.sync_method == "ntp_time":
-            if self.ntp_timestamp and self.ntp_date_time:
+            if len(self.measurements[NTPDatetimeSeries]) > 0 and options['SYNC_USING_NTP_DATETIME_SERIES']:
+                # This uses the median value for syncing
+                ntp = self.measurements[NTPDatetimeSeries]
+
+                dt = (ntp.time - ntp.ntp_datetime) / np.timedelta64(1, 'ms')
+                idx = (np.abs(dt - np.median(dt))).argmin()
+
                 for m in self.measurements.values():
-                    m.synchronize("ntp_time", self.ntp_timestamp, self.ntp_date_time,
+                    m.synchronize("ntp_time", ntp._time[idx],
+                                  ntp.ntp_datetime[idx],
+                                  timedelta_unit=self.timedelta_unit)
+            elif self.ntp_timestamp and self.ntp_date_time:
+                for m in self.measurements.values():
+                    m.synchronize("ntp_time", self.ntp_timestamp,
+                                  self.ntp_date_time,
                                   timedelta_unit=self.timedelta_unit)
             else:
                 logger.warning("(%s) No NTP timestamp and datetime, falling back to device_time synchronization" %
